@@ -17,6 +17,7 @@
 
 #include <stdint.h>
 
+#include "tls/s2n_certificate_keys.h"
 #include "tls/s2n_cipher_preferences.h"
 #include "tls/s2n_ecc_preferences.h"
 #include "tls/s2n_kem_preferences.h"
@@ -93,6 +94,11 @@ struct s2n_security_policy_selection {
 
 extern struct s2n_security_policy_selection security_policy_selection[];
 
+/* Defaults as of 05/24 */
+extern const struct s2n_security_policy security_policy_20240501;
+extern const struct s2n_security_policy security_policy_20240502;
+extern const struct s2n_security_policy security_policy_20240503;
+
 extern const struct s2n_security_policy security_policy_20140601;
 extern const struct s2n_security_policy security_policy_20141001;
 extern const struct s2n_security_policy security_policy_20150202;
